@@ -21,7 +21,11 @@ class ShadowedTextureMaterial : public ShadowedRectangleMaterial
 public:
     ShadowedTextureMaterial();
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QSGMaterialShader *createShader() const override;
+#else
+    QSGMaterialShader *createShader(QSGRendererInterface::RenderMode) const override;
+#endif
     QSGMaterialType *type() const override;
     int compare(const QSGMaterial *other) const override;
 
@@ -35,6 +39,11 @@ class ShadowedTextureShader : public ShadowedRectangleShader
 public:
     ShadowedTextureShader(ShadowedRectangleMaterial::ShaderType shaderType);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     void initialize() override;
     void updateState(const QSGMaterialShader::RenderState &state, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
+#else
+    void
+    updateSampledImage(QSGMaterialShader::RenderState &state, int binding, QSGTexture **texture, QSGMaterial *newMaterial, QSGMaterial *oldMaterial) override;
+#endif
 };
